# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: lara_django_data_grpc/v1/lara_django_data.proto
# Protobuf Python Version: 5.28.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    2,
    '',
    'lara_django_data_grpc/v1/lara_django_data.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/lara_django_data_grpc/v1/lara_django_data.proto\x12\x1clara_django.lara_django_data\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\"-\n\x12\x44\x61taDestroyRequest\x12\x17\n\x07\x64\x61ta_id\x18\x01 \x01(\tR\x06\x64\x61taId\"\x11\n\x0f\x44\x61taListRequest\"X\n\x10\x44\x61taListResponse\x12\x44\n\x07results\x18\x01 \x03(\x0b\x32*.lara_django.lara_django_data.DataResponseR\x07results\"\xd1\r\n\x18\x44\x61taPartialUpdateRequest\x12\x1c\n\x07\x64\x61ta_id\x18\x01 \x01(\tH\x00R\x06\x64\x61taId\x88\x01\x01\x12 \n\tdata_type\x18\x02 \x01(\tH\x01R\x08\x64\x61taType\x88\x01\x01\x12\"\n\nmedia_type\x18\x03 \x01(\tH\x02R\tmediaType\x88\x01\x01\x12\x1c\n\tnamespace\x18\x04 \x01(\tR\tnamespace\x12,\n\x0fmethod_instance\x18\x05 \x01(\tH\x03R\x0emethodInstance\x88\x01\x01\x12.\n\x10process_instance\x18\x06 \x01(\tH\x04R\x0fprocessInstance\x88\x01\x01\x12\x32\n\x12procedure_instance\x18\x07 \x01(\tH\x05R\x11procedureInstance\x88\x01\x01\x12\x14\n\x05users\x18\x08 \x03(\tR\x05users\x12\x16\n\x06groups\x18\t \x03(\tR\x06groups\x12&\n\x0evisualisations\x18\n \x03(\tR\x0evisualisations\x12\x1d\n\ndata_extra\x18\x0b \x03(\tR\tdataExtra\x12\x12\n\x04tags\x18\x0c \x03(\tR\x04tags\x12-\n\x12resources_external\x18\r \x03(\tR\x11resourcesExternal\x12\x33\n\x16_partial_update_fields\x18\x0e \x03(\tR\x13PartialUpdateFields\x12\x17\n\x04name\x18\x0f \x01(\tH\x06R\x04name\x88\x01\x01\x12\x1d\n\x07version\x18\x10 \x01(\tH\x07R\x07version\x88\x01\x01\x12 \n\tname_full\x18\x12 \x01(\tH\x08R\x08nameFull\x88\x01\x01\x12$\n\x0bhash_sha256\x18\x13 \x01(\tH\tR\nhashSha256\x88\x01\x01\x12,\n\x0fhash_blockchain\x18\x14 \x01(\tH\nR\x0ehashBlockchain\x88\x01\x01\x12.\n\x03\x61\x63l\x18\x15 \x01(\x0b\x32\x17.google.protobuf.StructH\x0bR\x03\x61\x63l\x88\x01\x01\x12\x38\n\x08licenses\x18\x16 \x01(\x0b\x32\x17.google.protobuf.StructH\x0cR\x08licenses\x88\x01\x01\x12.\n\x10\x64\x61tetime_created\x18\x17 \x01(\tH\rR\x0f\x64\x61tetimeCreated\x88\x01\x01\x12\x39\n\x16\x64\x61tetime_last_modified\x18\x18 \x01(\tH\x0eR\x14\x64\x61tetimeLastModified\x88\x01\x01\x12\x39\n\tdata_json\x18\x19 \x01(\x0b\x32\x17.google.protobuf.StructH\x0fR\x08\x64\x61taJson\x88\x01\x01\x12\x38\n\x08metadata\x18\x1a \x01(\x0b\x32\x17.google.protobuf.StructH\x10R\x08metadata\x88\x01\x01\x12\x15\n\x03iri\x18\x1b \x01(\tH\x11R\x03iri\x88\x01\x01\x12\x15\n\x03pid\x18\x1c \x01(\tH\x12R\x03pid\x88\x01\x01\x12\x15\n\x03\x64oi\x18\x1d \x01(\tH\x13R\x03\x64oi\x88\x01\x01\x12\x1a\n\x06pac_id\x18\x1e \x01(\tH\x14R\x05pacId\x88\x01\x01\x12\x17\n\x04\x66ile\x18\x1f \x01(\tH\x15R\x04\x66ile\x88\x01\x01\x12!\n\tthumbnail\x18  \x01(\tH\x16R\tthumbnail\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18! \x01(\tH\x17R\x0b\x64\x65scription\x88\x01\x01\x12\x1d\n\x07remarks\x18\" \x01(\tH\x18R\x07remarks\x88\x01\x01\x12&\n\x0cname_display\x18# \x01(\tH\x19R\x0bnameDisplay\x88\x01\x01\x12(\n\rsearch_vector\x18$ \x01(\tH\x1aR\x0csearchVector\x88\x01\x01\x42\n\n\x08_data_idB\x0c\n\n_data_typeB\r\n\x0b_media_typeB\x12\n\x10_method_instanceB\x13\n\x11_process_instanceB\x15\n\x13_procedure_instanceB\x07\n\x05_nameB\n\n\x08_versionB\x0c\n\n_name_fullB\x0e\n\x0c_hash_sha256B\x12\n\x10_hash_blockchainB\x06\n\x04_aclB\x0b\n\t_licensesB\x13\n\x11_datetime_createdB\x19\n\x17_datetime_last_modifiedB\x0c\n\n_data_jsonB\x0b\n\t_metadataB\x06\n\x04_iriB\x06\n\x04_pidB\x06\n\x04_doiB\t\n\x07_pac_idB\x07\n\x05_fileB\x0c\n\n_thumbnailB\x0e\n\x0c_descriptionB\n\n\x08_remarksB\x0f\n\r_name_displayB\x10\n\x0e_search_vector\"\x8f\r\n\x0b\x44\x61taRequest\x12\x1c\n\x07\x64\x61ta_id\x18\x01 \x01(\tH\x00R\x06\x64\x61taId\x88\x01\x01\x12 \n\tdata_type\x18\x02 \x01(\tH\x01R\x08\x64\x61taType\x88\x01\x01\x12\"\n\nmedia_type\x18\x03 \x01(\tH\x02R\tmediaType\x88\x01\x01\x12\x1c\n\tnamespace\x18\x04 \x01(\tR\tnamespace\x12,\n\x0fmethod_instance\x18\x05 \x01(\tH\x03R\x0emethodInstance\x88\x01\x01\x12.\n\x10process_instance\x18\x06 \x01(\tH\x04R\x0fprocessInstance\x88\x01\x01\x12\x32\n\x12procedure_instance\x18\x07 \x01(\tH\x05R\x11procedureInstance\x88\x01\x01\x12\x14\n\x05users\x18\x08 \x03(\tR\x05users\x12\x16\n\x06groups\x18\t \x03(\tR\x06groups\x12&\n\x0evisualisations\x18\n \x03(\tR\x0evisualisations\x12\x1d\n\ndata_extra\x18\x0b \x03(\tR\tdataExtra\x12\x12\n\x04tags\x18\x0c \x03(\tR\x04tags\x12-\n\x12resources_external\x18\r \x03(\tR\x11resourcesExternal\x12\x17\n\x04name\x18\x0e \x01(\tH\x06R\x04name\x88\x01\x01\x12\x1d\n\x07version\x18\x0f \x01(\tH\x07R\x07version\x88\x01\x01\x12 \n\tname_full\x18\x11 \x01(\tH\x08R\x08nameFull\x88\x01\x01\x12$\n\x0bhash_sha256\x18\x12 \x01(\tH\tR\nhashSha256\x88\x01\x01\x12,\n\x0fhash_blockchain\x18\x13 \x01(\tH\nR\x0ehashBlockchain\x88\x01\x01\x12.\n\x03\x61\x63l\x18\x14 \x01(\x0b\x32\x17.google.protobuf.StructH\x0bR\x03\x61\x63l\x88\x01\x01\x12\x38\n\x08licenses\x18\x15 \x01(\x0b\x32\x17.google.protobuf.StructH\x0cR\x08licenses\x88\x01\x01\x12.\n\x10\x64\x61tetime_created\x18\x16 \x01(\tH\rR\x0f\x64\x61tetimeCreated\x88\x01\x01\x12\x39\n\x16\x64\x61tetime_last_modified\x18\x17 \x01(\tH\x0eR\x14\x64\x61tetimeLastModified\x88\x01\x01\x12\x39\n\tdata_json\x18\x18 \x01(\x0b\x32\x17.google.protobuf.StructH\x0fR\x08\x64\x61taJson\x88\x01\x01\x12\x38\n\x08metadata\x18\x19 \x01(\x0b\x32\x17.google.protobuf.StructH\x10R\x08metadata\x88\x01\x01\x12\x15\n\x03iri\x18\x1a \x01(\tH\x11R\x03iri\x88\x01\x01\x12\x15\n\x03pid\x18\x1b \x01(\tH\x12R\x03pid\x88\x01\x01\x12\x15\n\x03\x64oi\x18\x1c \x01(\tH\x13R\x03\x64oi\x88\x01\x01\x12\x1a\n\x06pac_id\x18\x1d \x01(\tH\x14R\x05pacId\x88\x01\x01\x12\x17\n\x04\x66ile\x18\x1e \x01(\tH\x15R\x04\x66ile\x88\x01\x01\x12!\n\tthumbnail\x18\x1f \x01(\tH\x16R\tthumbnail\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18  \x01(\tH\x17R\x0b\x64\x65scription\x88\x01\x01\x12\x1d\n\x07remarks\x18! \x01(\tH\x18R\x07remarks\x88\x01\x01\x12&\n\x0cname_display\x18\" \x01(\tH\x19R\x0bnameDisplay\x88\x01\x01\x12(\n\rsearch_vector\x18# \x01(\tH\x1aR\x0csearchVector\x88\x01\x01\x42\n\n\x08_data_idB\x0c\n\n_data_typeB\r\n\x0b_media_typeB\x12\n\x10_method_instanceB\x13\n\x11_process_instanceB\x15\n\x13_procedure_instanceB\x07\n\x05_nameB\n\n\x08_versionB\x0c\n\n_name_fullB\x0e\n\x0c_hash_sha256B\x12\n\x10_hash_blockchainB\x06\n\x04_aclB\x0b\n\t_licensesB\x13\n\x11_datetime_createdB\x19\n\x17_datetime_last_modifiedB\x0c\n\n_data_jsonB\x0b\n\t_metadataB\x06\n\x04_iriB\x06\n\x04_pidB\x06\n\x04_doiB\t\n\x07_pac_idB\x07\n\x05_fileB\x0c\n\n_thumbnailB\x0e\n\x0c_descriptionB\n\n\x08_remarksB\x0f\n\r_name_displayB\x10\n\x0e_search_vector\"\x90\r\n\x0c\x44\x61taResponse\x12\x1c\n\x07\x64\x61ta_id\x18\x01 \x01(\tH\x00R\x06\x64\x61taId\x88\x01\x01\x12 \n\tdata_type\x18\x02 \x01(\tH\x01R\x08\x64\x61taType\x88\x01\x01\x12\"\n\nmedia_type\x18\x03 \x01(\tH\x02R\tmediaType\x88\x01\x01\x12\x1c\n\tnamespace\x18\x04 \x01(\tR\tnamespace\x12,\n\x0fmethod_instance\x18\x05 \x01(\tH\x03R\x0emethodInstance\x88\x01\x01\x12.\n\x10process_instance\x18\x06 \x01(\tH\x04R\x0fprocessInstance\x88\x01\x01\x12\x32\n\x12procedure_instance\x18\x07 \x01(\tH\x05R\x11procedureInstance\x88\x01\x01\x12\x14\n\x05users\x18\x08 \x03(\tR\x05users\x12\x16\n\x06groups\x18\t \x03(\tR\x06groups\x12&\n\x0evisualisations\x18\n \x03(\tR\x0evisualisations\x12\x1d\n\ndata_extra\x18\x0b \x03(\tR\tdataExtra\x12\x12\n\x04tags\x18\x0c \x03(\tR\x04tags\x12-\n\x12resources_external\x18\r \x03(\tR\x11resourcesExternal\x12\x17\n\x04name\x18\x0e \x01(\tH\x06R\x04name\x88\x01\x01\x12\x1d\n\x07version\x18\x0f \x01(\tH\x07R\x07version\x88\x01\x01\x12 \n\tname_full\x18\x11 \x01(\tH\x08R\x08nameFull\x88\x01\x01\x12$\n\x0bhash_sha256\x18\x12 \x01(\tH\tR\nhashSha256\x88\x01\x01\x12,\n\x0fhash_blockchain\x18\x13 \x01(\tH\nR\x0ehashBlockchain\x88\x01\x01\x12.\n\x03\x61\x63l\x18\x14 \x01(\x0b\x32\x17.google.protobuf.StructH\x0bR\x03\x61\x63l\x88\x01\x01\x12\x38\n\x08licenses\x18\x15 \x01(\x0b\x32\x17.google.protobuf.StructH\x0cR\x08licenses\x88\x01\x01\x12.\n\x10\x64\x61tetime_created\x18\x16 \x01(\tH\rR\x0f\x64\x61tetimeCreated\x88\x01\x01\x12\x39\n\x16\x64\x61tetime_last_modified\x18\x17 \x01(\tH\x0eR\x14\x64\x61tetimeLastModified\x88\x01\x01\x12\x39\n\tdata_json\x18\x18 \x01(\x0b\x32\x17.google.protobuf.StructH\x0fR\x08\x64\x61taJson\x88\x01\x01\x12\x38\n\x08metadata\x18\x19 \x01(\x0b\x32\x17.google.protobuf.StructH\x10R\x08metadata\x88\x01\x01\x12\x15\n\x03iri\x18\x1a \x01(\tH\x11R\x03iri\x88\x01\x01\x12\x15\n\x03pid\x18\x1b \x01(\tH\x12R\x03pid\x88\x01\x01\x12\x15\n\x03\x64oi\x18\x1c \x01(\tH\x13R\x03\x64oi\x88\x01\x01\x12\x1a\n\x06pac_id\x18\x1d \x01(\tH\x14R\x05pacId\x88\x01\x01\x12\x17\n\x04\x66ile\x18\x1e \x01(\tH\x15R\x04\x66ile\x88\x01\x01\x12!\n\tthumbnail\x18\x1f \x01(\tH\x16R\tthumbnail\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18  \x01(\tH\x17R\x0b\x64\x65scription\x88\x01\x01\x12\x1d\n\x07remarks\x18! \x01(\tH\x18R\x07remarks\x88\x01\x01\x12&\n\x0cname_display\x18\" \x01(\tH\x19R\x0bnameDisplay\x88\x01\x01\x12(\n\rsearch_vector\x18# \x01(\tH\x1aR\x0csearchVector\x88\x01\x01\x42\n\n\x08_data_idB\x0c\n\n_data_typeB\r\n\x0b_media_typeB\x12\n\x10_method_instanceB\x13\n\x11_process_instanceB\x15\n\x13_procedure_instanceB\x07\n\x05_nameB\n\n\x08_versionB\x0c\n\n_name_fullB\x0e\n\x0c_hash_sha256B\x12\n\x10_hash_blockchainB\x06\n\x04_aclB\x0b\n\t_licensesB\x13\n\x11_datetime_createdB\x19\n\x17_datetime_last_modifiedB\x0c\n\n_data_jsonB\x0b\n\t_metadataB\x06\n\x04_iriB\x06\n\x04_pidB\x06\n\x04_doiB\t\n\x07_pac_idB\x07\n\x05_fileB\x0c\n\n_thumbnailB\x0e\n\x0c_descriptionB\n\n\x08_remarksB\x0f\n\r_name_displayB\x10\n\x0e_search_vector\"V\n\x1b\x44\x61taRetrieveByNameNSRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12#\n\rnamespace_uri\x18\x02 \x01(\tR\x0cnamespaceUri\".\n\x13\x44\x61taRetrieveRequest\x12\x17\n\x07\x64\x61ta_id\x18\x01 \x01(\tR\x06\x64\x61taId\"\x13\n\x11\x44\x61taStreamRequest\"?\n\x18\x44\x61taSubsetDestroyRequest\x12#\n\rdatasubset_id\x18\x01 \x01(\tR\x0c\x64\x61tasubsetId\"\x17\n\x15\x44\x61taSubsetListRequest\"d\n\x16\x44\x61taSubsetListResponse\x12J\n\x07results\x18\x01 \x03(\x0b\x32\x30.lara_django.lara_django_data.DataSubsetResponseR\x07results\"\xee\x03\n\x1e\x44\x61taSubsetPartialUpdateRequest\x12(\n\rdatasubset_id\x18\x01 \x01(\tH\x00R\x0c\x64\x61tasubsetId\x88\x01\x01\x12\x1c\n\tnamespace\x18\x02 \x01(\tR\tnamespace\x12\x19\n\x05group\x18\x04 \x01(\tH\x01R\x05group\x88\x01\x01\x12\x12\n\x04\x64\x61ta\x18\x05 \x03(\tR\x04\x64\x61ta\x12\x12\n\x04tags\x18\x06 \x03(\tR\x04tags\x12\x33\n\x16_partial_update_fields\x18\x07 \x03(\tR\x13PartialUpdateFields\x12\x12\n\x04name\x18\x08 \x01(\tR\x04name\x12%\n\x0b\x64\x65scription\x18\t \x01(\tH\x02R\x0b\x64\x65scription\x88\x01\x01\x12\x39\n\x16\x64\x61tetime_last_modified\x18\n \x01(\tH\x03R\x14\x64\x61tetimeLastModified\x88\x01\x01\x12&\n\x0cname_display\x18\x0b \x01(\tH\x04R\x0bnameDisplay\x88\x01\x01\x12\x16\n\x06\x65ntity\x18\x0c \x01(\tR\x06\x65ntityB\x10\n\x0e_datasubset_idB\x08\n\x06_groupB\x0e\n\x0c_descriptionB\x19\n\x17_datetime_last_modifiedB\x0f\n\r_name_display\"\xac\x03\n\x11\x44\x61taSubsetRequest\x12(\n\rdatasubset_id\x18\x01 \x01(\tH\x00R\x0c\x64\x61tasubsetId\x88\x01\x01\x12\x1c\n\tnamespace\x18\x02 \x01(\tR\tnamespace\x12\x19\n\x05group\x18\x04 \x01(\tH\x01R\x05group\x88\x01\x01\x12\x12\n\x04\x64\x61ta\x18\x05 \x03(\tR\x04\x64\x61ta\x12\x12\n\x04tags\x18\x06 \x03(\tR\x04tags\x12\x12\n\x04name\x18\x07 \x01(\tR\x04name\x12%\n\x0b\x64\x65scription\x18\x08 \x01(\tH\x02R\x0b\x64\x65scription\x88\x01\x01\x12\x39\n\x16\x64\x61tetime_last_modified\x18\t \x01(\tH\x03R\x14\x64\x61tetimeLastModified\x88\x01\x01\x12&\n\x0cname_display\x18\n \x01(\tH\x04R\x0bnameDisplay\x88\x01\x01\x12\x16\n\x06\x65ntity\x18\x0b \x01(\tR\x06\x65ntityB\x10\n\x0e_datasubset_idB\x08\n\x06_groupB\x0e\n\x0c_descriptionB\x19\n\x17_datetime_last_modifiedB\x0f\n\r_name_display\"\xad\x03\n\x12\x44\x61taSubsetResponse\x12(\n\rdatasubset_id\x18\x01 \x01(\tH\x00R\x0c\x64\x61tasubsetId\x88\x01\x01\x12\x1c\n\tnamespace\x18\x02 \x01(\tR\tnamespace\x12\x19\n\x05group\x18\x04 \x01(\tH\x01R\x05group\x88\x01\x01\x12\x12\n\x04\x64\x61ta\x18\x05 \x03(\tR\x04\x64\x61ta\x12\x12\n\x04tags\x18\x06 \x03(\tR\x04tags\x12\x12\n\x04name\x18\x07 \x01(\tR\x04name\x12%\n\x0b\x64\x65scription\x18\x08 \x01(\tH\x02R\x0b\x64\x65scription\x88\x01\x01\x12\x39\n\x16\x64\x61tetime_last_modified\x18\t \x01(\tH\x03R\x14\x64\x61tetimeLastModified\x88\x01\x01\x12&\n\x0cname_display\x18\n \x01(\tH\x04R\x0bnameDisplay\x88\x01\x01\x12\x16\n\x06\x65ntity\x18\x0b \x01(\tR\x06\x65ntityB\x10\n\x0e_datasubset_idB\x08\n\x06_groupB\x0e\n\x0c_descriptionB\x19\n\x17_datetime_last_modifiedB\x0f\n\r_name_display\"@\n\x19\x44\x61taSubsetRetrieveRequest\x12#\n\rdatasubset_id\x18\x01 \x01(\tR\x0c\x64\x61tasubsetId\"\x19\n\x17\x44\x61taSubsetStreamRequest\"?\n\x18\x45valuationDestroyRequest\x12#\n\revaluation_id\x18\x01 \x01(\tR\x0c\x65valuationId\"\x17\n\x15\x45valuationListRequest\"d\n\x16\x45valuationListResponse\x12J\n\x07results\x18\x01 \x03(\x0b\x32\x30.lara_django.lara_django_data.EvaluationResponseR\x07results\"\xd0\t\n\x1e\x45valuationPartialUpdateRequest\x12(\n\revaluation_id\x18\x01 \x01(\tH\x00R\x0c\x65valuationId\x88\x01\x01\x12\x1c\n\tnamespace\x18\x02 \x01(\tR\tnamespace\x12\x35\n\x14\x65val_method_instance\x18\x03 \x01(\tH\x01R\x12\x65valMethodInstance\x88\x01\x01\x12;\n\x17\x65val_procedure_instance\x18\x04 \x01(\tH\x02R\x15\x65valProcedureInstance\x88\x01\x01\x12!\n\x0cparent_evals\x18\x05 \x03(\tR\x0bparentEvals\x12\x1b\n\tdata_eval\x18\x06 \x03(\tR\x08\x64\x61taEval\x12!\n\x0c\x64\x61ta_results\x18\x07 \x03(\tR\x0b\x64\x61taResults\x12&\n\x0evisualisations\x18\x08 \x03(\tR\x0evisualisations\x12\x12\n\x04tags\x18\t \x03(\tR\x04tags\x12-\n\x12resources_external\x18\n \x03(\tR\x11resourcesExternal\x12\x33\n\x16_partial_update_fields\x18\x0b \x03(\tR\x13PartialUpdateFields\x12\x12\n\x04name\x18\x0c \x01(\tR\x04name\x12\x1d\n\x07version\x18\r \x01(\tH\x03R\x07version\x88\x01\x01\x12$\n\x0bhash_sha256\x18\x0e \x01(\tH\x04R\nhashSha256\x88\x01\x01\x12<\n\nparameters\x18\x0f \x01(\x0b\x32\x17.google.protobuf.StructH\x05R\nparameters\x88\x01\x01\x12\x15\n\x03iri\x18\x10 \x01(\tH\x06R\x03iri\x88\x01\x01\x12\x15\n\x03pid\x18\x11 \x01(\tH\x07R\x03pid\x88\x01\x01\x12\x15\n\x03\x64oi\x18\x12 \x01(\tH\x08R\x03\x64oi\x88\x01\x01\x12\x36\n\x07\x63\x61ption\x18\x13 \x01(\x0b\x32\x17.google.protobuf.StructH\tR\x07\x63\x61ption\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x14 \x01(\tH\nR\x0b\x64\x65scription\x88\x01\x01\x12.\n\x10\x64\x61tetime_created\x18\x15 \x01(\tH\x0bR\x0f\x64\x61tetimeCreated\x88\x01\x01\x12\x39\n\x16\x64\x61tetime_last_modified\x18\x16 \x01(\tH\x0cR\x14\x64\x61tetimeLastModified\x88\x01\x01\x12&\n\x0cname_display\x18\x17 \x01(\tH\rR\x0bnameDisplay\x88\x01\x01\x12(\n\rsearch_vector\x18\x18 \x01(\tH\x0eR\x0csearchVector\x88\x01\x01\x42\x10\n\x0e_evaluation_idB\x17\n\x15_eval_method_instanceB\x1a\n\x18_eval_procedure_instanceB\n\n\x08_versionB\x0e\n\x0c_hash_sha256B\r\n\x0b_parametersB\x06\n\x04_iriB\x06\n\x04_pidB\x06\n\x04_doiB\n\n\x08_captionB\x0e\n\x0c_descriptionB\x13\n\x11_datetime_createdB\x19\n\x17_datetime_last_modifiedB\x0f\n\r_name_displayB\x10\n\x0e_search_vector\"\x8e\t\n\x11\x45valuationRequest\x12(\n\revaluation_id\x18\x01 \x01(\tH\x00R\x0c\x65valuationId\x88\x01\x01\x12\x1c\n\tnamespace\x18\x02 \x01(\tR\tnamespace\x12\x35\n\x14\x65val_method_instance\x18\x03 \x01(\tH\x01R\x12\x65valMethodInstance\x88\x01\x01\x12;\n\x17\x65val_procedure_instance\x18\x04 \x01(\tH\x02R\x15\x65valProcedureInstance\x88\x01\x01\x12!\n\x0cparent_evals\x18\x05 \x03(\tR\x0bparentEvals\x12\x1b\n\tdata_eval\x18\x06 \x03(\tR\x08\x64\x61taEval\x12!\n\x0c\x64\x61ta_results\x18\x07 \x03(\tR\x0b\x64\x61taResults\x12&\n\x0evisualisations\x18\x08 \x03(\tR\x0evisualisations\x12\x12\n\x04tags\x18\t \x03(\tR\x04tags\x12-\n\x12resources_external\x18\n \x03(\tR\x11resourcesExternal\x12\x12\n\x04name\x18\x0b \x01(\tR\x04name\x12\x1d\n\x07version\x18\x0c \x01(\tH\x03R\x07version\x88\x01\x01\x12$\n\x0bhash_sha256\x18\r \x01(\tH\x04R\nhashSha256\x88\x01\x01\x12<\n\nparameters\x18\x0e \x01(\x0b\x32\x17.google.protobuf.StructH\x05R\nparameters\x88\x01\x01\x12\x15\n\x03iri\x18\x0f \x01(\tH\x06R\x03iri\x88\x01\x01\x12\x15\n\x03pid\x18\x10 \x01(\tH\x07R\x03pid\x88\x01\x01\x12\x15\n\x03\x64oi\x18\x11 \x01(\tH\x08R\x03\x64oi\x88\x01\x01\x12\x36\n\x07\x63\x61ption\x18\x12 \x01(\x0b\x32\x17.google.protobuf.StructH\tR\x07\x63\x61ption\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x13 \x01(\tH\nR\x0b\x64\x65scription\x88\x01\x01\x12.\n\x10\x64\x61tetime_created\x18\x14 \x01(\tH\x0bR\x0f\x64\x61tetimeCreated\x88\x01\x01\x12\x39\n\x16\x64\x61tetime_last_modified\x18\x15 \x01(\tH\x0cR\x14\x64\x61tetimeLastModified\x88\x01\x01\x12&\n\x0cname_display\x18\x16 \x01(\tH\rR\x0bnameDisplay\x88\x01\x01\x12(\n\rsearch_vector\x18\x17 \x01(\tH\x0eR\x0csearchVector\x88\x01\x01\x42\x10\n\x0e_evaluation_idB\x17\n\x15_eval_method_instanceB\x1a\n\x18_eval_procedure_instanceB\n\n\x08_versionB\x0e\n\x0c_hash_sha256B\r\n\x0b_parametersB\x06\n\x04_iriB\x06\n\x04_pidB\x06\n\x04_doiB\n\n\x08_captionB\x0e\n\x0c_descriptionB\x13\n\x11_datetime_createdB\x19\n\x17_datetime_last_modifiedB\x0f\n\r_name_displayB\x10\n\x0e_search_vector\"\x8f\t\n\x12\x45valuationResponse\x12(\n\revaluation_id\x18\x01 \x01(\tH\x00R\x0c\x65valuationId\x88\x01\x01\x12\x1c\n\tnamespace\x18\x02 \x01(\tR\tnamespace\x12\x35\n\x14\x65val_method_instance\x18\x03 \x01(\tH\x01R\x12\x65valMethodInstance\x88\x01\x01\x12;\n\x17\x65val_procedure_instance\x18\x04 \x01(\tH\x02R\x15\x65valProcedureInstance\x88\x01\x01\x12!\n\x0cparent_evals\x18\x05 \x03(\tR\x0bparentEvals\x12\x1b\n\tdata_eval\x18\x06 \x03(\tR\x08\x64\x61taEval\x12!\n\x0c\x64\x61ta_results\x18\x07 \x03(\tR\x0b\x64\x61taResults\x12&\n\x0evisualisations\x18\x08 \x03(\tR\x0evisualisations\x12\x12\n\x04tags\x18\t \x03(\tR\x04tags\x12-\n\x12resources_external\x18\n \x03(\tR\x11resourcesExternal\x12\x12\n\x04name\x18\x0b \x01(\tR\x04name\x12\x1d\n\x07version\x18\x0c \x01(\tH\x03R\x07version\x88\x01\x01\x12$\n\x0bhash_sha256\x18\r \x01(\tH\x04R\nhashSha256\x88\x01\x01\x12<\n\nparameters\x18\x0e \x01(\x0b\x32\x17.google.protobuf.StructH\x05R\nparameters\x88\x01\x01\x12\x15\n\x03iri\x18\x0f \x01(\tH\x06R\x03iri\x88\x01\x01\x12\x15\n\x03pid\x18\x10 \x01(\tH\x07R\x03pid\x88\x01\x01\x12\x15\n\x03\x64oi\x18\x11 \x01(\tH\x08R\x03\x64oi\x88\x01\x01\x12\x36\n\x07\x63\x61ption\x18\x12 \x01(\x0b\x32\x17.google.protobuf.StructH\tR\x07\x63\x61ption\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x13 \x01(\tH\nR\x0b\x64\x65scription\x88\x01\x01\x12.\n\x10\x64\x61tetime_created\x18\x14 \x01(\tH\x0bR\x0f\x64\x61tetimeCreated\x88\x01\x01\x12\x39\n\x16\x64\x61tetime_last_modified\x18\x15 \x01(\tH\x0cR\x14\x64\x61tetimeLastModified\x88\x01\x01\x12&\n\x0cname_display\x18\x16 \x01(\tH\rR\x0bnameDisplay\x88\x01\x01\x12(\n\rsearch_vector\x18\x17 \x01(\tH\x0eR\x0csearchVector\x88\x01\x01\x42\x10\n\x0e_evaluation_idB\x17\n\x15_eval_method_instanceB\x1a\n\x18_eval_procedure_instanceB\n\n\x08_versionB\x0e\n\x0c_hash_sha256B\r\n\x0b_parametersB\x06\n\x04_iriB\x06\n\x04_pidB\x06\n\x04_doiB\n\n\x08_captionB\x0e\n\x0c_descriptionB\x13\n\x11_datetime_createdB\x19\n\x17_datetime_last_modifiedB\x0f\n\r_name_displayB\x10\n\x0e_search_vector\"\\\n!EvaluationRetrieveByNameNSRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12#\n\rnamespace_uri\x18\x02 \x01(\tR\x0cnamespaceUri\"@\n\x19\x45valuationRetrieveRequest\x12#\n\revaluation_id\x18\x01 \x01(\tR\x0c\x65valuationId\"\x19\n\x17\x45valuationStreamRequest\"<\n\x17\x45xtraDataDestroyRequest\x12!\n\x0c\x65xtradata_id\x18\x01 \x01(\tR\x0b\x65xtradataId\"\x16\n\x14\x45xtraDataListRequest\"b\n\x15\x45xtraDataListResponse\x12I\n\x07results\x18\x01 \x03(\x0b\x32/.lara_django.lara_django_data.ExtraDataResponseR\x07results\"\xb7\x07\n\x1d\x45xtraDataPartialUpdateRequest\x12&\n\x0c\x65xtradata_id\x18\x01 \x01(\tH\x00R\x0b\x65xtradataId\x88\x01\x01\x12 \n\tdata_type\x18\x02 \x01(\tH\x01R\x08\x64\x61taType\x88\x01\x01\x12\x1c\n\tnamespace\x18\x03 \x01(\tR\tnamespace\x12\"\n\nmedia_type\x18\x04 \x01(\tH\x02R\tmediaType\x88\x01\x01\x12\x33\n\x16_partial_update_fields\x18\x05 \x03(\tR\x13PartialUpdateFields\x12\x12\n\x04name\x18\x07 \x01(\tR\x04name\x12 \n\tname_full\x18\x08 \x01(\tH\x03R\x08nameFull\x88\x01\x01\x12\x18\n\x07version\x18\t \x01(\tR\x07version\x12$\n\x0bhash_sha256\x18\n \x01(\tH\x04R\nhashSha256\x88\x01\x01\x12\x39\n\tdata_json\x18\x0b \x01(\x0b\x32\x17.google.protobuf.StructH\x05R\x08\x64\x61taJson\x88\x01\x01\x12\x15\n\x03iri\x18\x0c \x01(\tH\x06R\x03iri\x88\x01\x01\x12\x15\n\x03url\x18\r \x01(\tH\x07R\x03url\x88\x01\x01\x12.\n\x10\x64\x61tetime_created\x18\x0e \x01(\tH\x08R\x0f\x64\x61tetimeCreated\x88\x01\x01\x12\x39\n\x16\x64\x61tetime_last_modified\x18\x0f \x01(\tH\tR\x14\x64\x61tetimeLastModified\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x10 \x01(\tH\nR\x0b\x64\x65scription\x88\x01\x01\x12\x17\n\x04\x66ile\x18\x11 \x01(\tH\x0bR\x04\x66ile\x88\x01\x01\x12\x19\n\x05image\x18\x12 \x01(\tH\x0cR\x05image\x88\x01\x01\x12&\n\x0cname_display\x18\x13 \x01(\tH\rR\x0bnameDisplay\x88\x01\x01\x12(\n\rsearch_vector\x18\x14 \x01(\tH\x0eR\x0csearchVector\x88\x01\x01\x42\x0f\n\r_extradata_idB\x0c\n\n_data_typeB\r\n\x0b_media_typeB\x0c\n\n_name_fullB\x0e\n\x0c_hash_sha256B\x0c\n\n_data_jsonB\x06\n\x04_iriB\x06\n\x04_urlB\x13\n\x11_datetime_createdB\x19\n\x17_datetime_last_modifiedB\x0e\n\x0c_descriptionB\x07\n\x05_fileB\x08\n\x06_imageB\x0f\n\r_name_displayB\x10\n\x0e_search_vector\"\xf5\x06\n\x10\x45xtraDataRequest\x12&\n\x0c\x65xtradata_id\x18\x01 \x01(\tH\x00R\x0b\x65xtradataId\x88\x01\x01\x12 \n\tdata_type\x18\x02 \x01(\tH\x01R\x08\x64\x61taType\x88\x01\x01\x12\x1c\n\tnamespace\x18\x03 \x01(\tR\tnamespace\x12\"\n\nmedia_type\x18\x04 \x01(\tH\x02R\tmediaType\x88\x01\x01\x12\x12\n\x04name\x18\x06 \x01(\tR\x04name\x12 \n\tname_full\x18\x07 \x01(\tH\x03R\x08nameFull\x88\x01\x01\x12\x18\n\x07version\x18\x08 \x01(\tR\x07version\x12$\n\x0bhash_sha256\x18\t \x01(\tH\x04R\nhashSha256\x88\x01\x01\x12\x39\n\tdata_json\x18\n \x01(\x0b\x32\x17.google.protobuf.StructH\x05R\x08\x64\x61taJson\x88\x01\x01\x12\x15\n\x03iri\x18\x0b \x01(\tH\x06R\x03iri\x88\x01\x01\x12\x15\n\x03url\x18\x0c \x01(\tH\x07R\x03url\x88\x01\x01\x12.\n\x10\x64\x61tetime_created\x18\r \x01(\tH\x08R\x0f\x64\x61tetimeCreated\x88\x01\x01\x12\x39\n\x16\x64\x61tetime_last_modified\x18\x0e \x01(\tH\tR\x14\x64\x61tetimeLastModified\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x0f \x01(\tH\nR\x0b\x64\x65scription\x88\x01\x01\x12\x17\n\x04\x66ile\x18\x10 \x01(\tH\x0bR\x04\x66ile\x88\x01\x01\x12\x19\n\x05image\x18\x11 \x01(\tH\x0cR\x05image\x88\x01\x01\x12&\n\x0cname_display\x18\x12 \x01(\tH\rR\x0bnameDisplay\x88\x01\x01\x12(\n\rsearch_vector\x18\x13 \x01(\tH\x0eR\x0csearchVector\x88\x01\x01\x42\x0f\n\r_extradata_idB\x0c\n\n_data_typeB\r\n\x0b_media_typeB\x0c\n\n_name_fullB\x0e\n\x0c_hash_sha256B\x0c\n\n_data_jsonB\x06\n\x04_iriB\x06\n\x04_urlB\x13\n\x11_datetime_createdB\x19\n\x17_datetime_last_modifiedB\x0e\n\x0c_descriptionB\x07\n\x05_fileB\x08\n\x06_imageB\x0f\n\r_name_displayB\x10\n\x0e_search_vector\"\xf6\x06\n\x11\x45xtraDataResponse\x12&\n\x0c\x65xtradata_id\x18\x01 \x01(\tH\x00R\x0b\x65xtradataId\x88\x01\x01\x12 \n\tdata_type\x18\x02 \x01(\tH\x01R\x08\x64\x61taType\x88\x01\x01\x12\x1c\n\tnamespace\x18\x03 \x01(\tR\tnamespace\x12\"\n\nmedia_type\x18\x04 \x01(\tH\x02R\tmediaType\x88\x01\x01\x12\x12\n\x04name\x18\x06 \x01(\tR\x04name\x12 \n\tname_full\x18\x07 \x01(\tH\x03R\x08nameFull\x88\x01\x01\x12\x18\n\x07version\x18\x08 \x01(\tR\x07version\x12$\n\x0bhash_sha256\x18\t \x01(\tH\x04R\nhashSha256\x88\x01\x01\x12\x39\n\tdata_json\x18\n \x01(\x0b\x32\x17.google.protobuf.StructH\x05R\x08\x64\x61taJson\x88\x01\x01\x12\x15\n\x03iri\x18\x0b \x01(\tH\x06R\x03iri\x88\x01\x01\x12\x15\n\x03url\x18\x0c \x01(\tH\x07R\x03url\x88\x01\x01\x12.\n\x10\x64\x61tetime_created\x18\r \x01(\tH\x08R\x0f\x64\x61tetimeCreated\x88\x01\x01\x12\x39\n\x16\x64\x61tetime_last_modified\x18\x0e \x01(\tH\tR\x14\x64\x61tetimeLastModified\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x0f \x01(\tH\nR\x0b\x64\x65scription\x88\x01\x01\x12\x17\n\x04\x66ile\x18\x10 \x01(\tH\x0bR\x04\x66ile\x88\x01\x01\x12\x19\n\x05image\x18\x11 \x01(\tH\x0cR\x05image\x88\x01\x01\x12&\n\x0cname_display\x18\x12 \x01(\tH\rR\x0bnameDisplay\x88\x01\x01\x12(\n\rsearch_vector\x18\x13 \x01(\tH\x0eR\x0csearchVector\x88\x01\x01\x42\x0f\n\r_extradata_idB\x0c\n\n_data_typeB\r\n\x0b_media_typeB\x0c\n\n_name_fullB\x0e\n\x0c_hash_sha256B\x0c\n\n_data_jsonB\x06\n\x04_iriB\x06\n\x04_urlB\x13\n\x11_datetime_createdB\x19\n\x17_datetime_last_modifiedB\x0e\n\x0c_descriptionB\x07\n\x05_fileB\x08\n\x06_imageB\x0f\n\r_name_displayB\x10\n\x0e_search_vector\"=\n\x18\x45xtraDataRetrieveRequest\x12!\n\x0c\x65xtradata_id\x18\x01 \x01(\tR\x0b\x65xtradataId\"\x18\n\x16\x45xtraDataStreamRequest\"]\n\x11\x46ileDownloadChunk\x12\x1a\n\x08\x66ilename\x18\x01 \x01(\tR\x08\x66ilename\x12\x12\n\x04\x64\x61ta\x18\x02 \x01(\x0cR\x04\x64\x61ta\x12\x18\n\x07success\x18\x03 \x01(\x08R\x07success\"J\n\x10\x46ileDownloadInfo\x12\x17\n\x07item_id\x18\x01 \x01(\tR\x06itemId\x12\x1d\n\nchunk_size\x18\x02 \x01(\x04R\tchunkSize\"g\n\x0f\x46ileUploadChunk\x12\x1a\n\x08\x66ilename\x18\x01 \x01(\tR\x08\x66ilename\x12$\n\x0eupdate_item_id\x18\x02 \x01(\tR\x0cupdateItemId\x12\x12\n\x04\x64\x61ta\x18\x03 \x01(\x0cR\x04\x64\x61ta\"*\n\x0e\x46ileUploadInfo\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\"i\n\x12ImageDownloadChunk\x12%\n\x0e\x66ilename_image\x18\x01 \x01(\tR\rfilenameImage\x12\x12\n\x04\x64\x61ta\x18\x02 \x01(\x0cR\x04\x64\x61ta\x12\x18\n\x07success\x18\x03 \x01(\x08R\x07success\"K\n\x11ImageDownloadInfo\x12\x17\n\x07item_id\x18\x01 \x01(\tR\x06itemId\x12\x1d\n\nchunk_size\x18\x02 \x01(\x04R\tchunkSize\"h\n\x10ImageUploadChunk\x12\x1a\n\x08\x66ilename\x18\x01 \x01(\tR\x08\x66ilename\x12$\n\x0eupdate_item_id\x18\x02 \x01(\tR\x0cupdateItemId\x12\x12\n\x04\x64\x61ta\x18\x03 \x01(\x0cR\x04\x64\x61ta\"+\n\x0fImageUploadInfo\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\"H\n\x1bVisualisationDestroyRequest\x12)\n\x10visualisation_id\x18\x01 \x01(\tR\x0fvisualisationId\"\x1a\n\x18VisualisationListRequest\"j\n\x19VisualisationListResponse\x12M\n\x07results\x18\x01 \x03(\x0b\x32\x33.lara_django.lara_django_data.VisualisationResponseR\x07results\"\xbd\t\n!VisualisationPartialUpdateRequest\x12.\n\x10visualisation_id\x18\x01 \x01(\tH\x00R\x0fvisualisationId\x88\x01\x01\x12\x1c\n\tnamespace\x18\x02 \x01(\tR\tnamespace\x12 \n\tdata_type\x18\x03 \x01(\tH\x01R\x08\x64\x61taType\x88\x01\x01\x12=\n\x18plotting_method_instance\x18\x04 \x01(\tH\x02R\x16plottingMethodInstance\x88\x01\x01\x12\x43\n\x1bplotting_procedure_instance\x18\x05 \x01(\tH\x03R\x19plottingProcedureInstance\x88\x01\x01\x12\x12\n\x04tags\x18\x06 \x03(\tR\x04tags\x12-\n\x12resources_external\x18\x07 \x03(\tR\x11resourcesExternal\x12\x33\n\x16_partial_update_fields\x18\x08 \x03(\tR\x13PartialUpdateFields\x12\x12\n\x04name\x18\t \x01(\tR\x04name\x12\x1d\n\x07version\x18\n \x01(\tH\x04R\x07version\x88\x01\x01\x12O\n\x14rendering_components\x18\x0b \x01(\x0b\x32\x17.google.protobuf.StructH\x05R\x13renderingComponents\x88\x01\x01\x12\x15\n\x03iri\x18\x0c \x01(\tH\x06R\x03iri\x88\x01\x01\x12\x36\n\x07\x63\x61ption\x18\r \x01(\x0b\x32\x17.google.protobuf.StructH\x07R\x07\x63\x61ption\x88\x01\x01\x12!\n\tthumbnail\x18\x0e \x01(\tH\x08R\tthumbnail\x88\x01\x01\x12\x19\n\x05image\x18\x0f \x01(\tH\tR\x05image\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x10 \x01(\tH\nR\x0b\x64\x65scription\x88\x01\x01\x12.\n\x10\x64\x61tetime_created\x18\x11 \x01(\tH\x0bR\x0f\x64\x61tetimeCreated\x88\x01\x01\x12\x39\n\x16\x64\x61tetime_last_modified\x18\x12 \x01(\tH\x0cR\x14\x64\x61tetimeLastModified\x88\x01\x01\x12&\n\x0cname_display\x18\x13 \x01(\tH\rR\x0bnameDisplay\x88\x01\x01\x12\x19\n\x05order\x18\x14 \x01(\x05H\x0eR\x05order\x88\x01\x01\x12(\n\rsearch_vector\x18\x15 \x01(\tH\x0fR\x0csearchVector\x88\x01\x01\x42\x13\n\x11_visualisation_idB\x0c\n\n_data_typeB\x1b\n\x19_plotting_method_instanceB\x1e\n\x1c_plotting_procedure_instanceB\n\n\x08_versionB\x17\n\x15_rendering_componentsB\x06\n\x04_iriB\n\n\x08_captionB\x0c\n\n_thumbnailB\x08\n\x06_imageB\x0e\n\x0c_descriptionB\x13\n\x11_datetime_createdB\x19\n\x17_datetime_last_modifiedB\x0f\n\r_name_displayB\x08\n\x06_orderB\x10\n\x0e_search_vector\"\xfb\x08\n\x14VisualisationRequest\x12.\n\x10visualisation_id\x18\x01 \x01(\tH\x00R\x0fvisualisationId\x88\x01\x01\x12\x1c\n\tnamespace\x18\x02 \x01(\tR\tnamespace\x12 \n\tdata_type\x18\x03 \x01(\tH\x01R\x08\x64\x61taType\x88\x01\x01\x12=\n\x18plotting_method_instance\x18\x04 \x01(\tH\x02R\x16plottingMethodInstance\x88\x01\x01\x12\x43\n\x1bplotting_procedure_instance\x18\x05 \x01(\tH\x03R\x19plottingProcedureInstance\x88\x01\x01\x12\x12\n\x04tags\x18\x06 \x03(\tR\x04tags\x12-\n\x12resources_external\x18\x07 \x03(\tR\x11resourcesExternal\x12\x12\n\x04name\x18\x08 \x01(\tR\x04name\x12\x1d\n\x07version\x18\t \x01(\tH\x04R\x07version\x88\x01\x01\x12O\n\x14rendering_components\x18\n \x01(\x0b\x32\x17.google.protobuf.StructH\x05R\x13renderingComponents\x88\x01\x01\x12\x15\n\x03iri\x18\x0b \x01(\tH\x06R\x03iri\x88\x01\x01\x12\x36\n\x07\x63\x61ption\x18\x0c \x01(\x0b\x32\x17.google.protobuf.StructH\x07R\x07\x63\x61ption\x88\x01\x01\x12!\n\tthumbnail\x18\r \x01(\tH\x08R\tthumbnail\x88\x01\x01\x12\x19\n\x05image\x18\x0e \x01(\tH\tR\x05image\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x0f \x01(\tH\nR\x0b\x64\x65scription\x88\x01\x01\x12.\n\x10\x64\x61tetime_created\x18\x10 \x01(\tH\x0bR\x0f\x64\x61tetimeCreated\x88\x01\x01\x12\x39\n\x16\x64\x61tetime_last_modified\x18\x11 \x01(\tH\x0cR\x14\x64\x61tetimeLastModified\x88\x01\x01\x12&\n\x0cname_display\x18\x12 \x01(\tH\rR\x0bnameDisplay\x88\x01\x01\x12\x19\n\x05order\x18\x13 \x01(\x05H\x0eR\x05order\x88\x01\x01\x12(\n\rsearch_vector\x18\x14 \x01(\tH\x0fR\x0csearchVector\x88\x01\x01\x42\x13\n\x11_visualisation_idB\x0c\n\n_data_typeB\x1b\n\x19_plotting_method_instanceB\x1e\n\x1c_plotting_procedure_instanceB\n\n\x08_versionB\x17\n\x15_rendering_componentsB\x06\n\x04_iriB\n\n\x08_captionB\x0c\n\n_thumbnailB\x08\n\x06_imageB\x0e\n\x0c_descriptionB\x13\n\x11_datetime_createdB\x19\n\x17_datetime_last_modifiedB\x0f\n\r_name_displayB\x08\n\x06_orderB\x10\n\x0e_search_vector\"\xfc\x08\n\x15VisualisationResponse\x12.\n\x10visualisation_id\x18\x01 \x01(\tH\x00R\x0fvisualisationId\x88\x01\x01\x12\x1c\n\tnamespace\x18\x02 \x01(\tR\tnamespace\x12 \n\tdata_type\x18\x03 \x01(\tH\x01R\x08\x64\x61taType\x88\x01\x01\x12=\n\x18plotting_method_instance\x18\x04 \x01(\tH\x02R\x16plottingMethodInstance\x88\x01\x01\x12\x43\n\x1bplotting_procedure_instance\x18\x05 \x01(\tH\x03R\x19plottingProcedureInstance\x88\x01\x01\x12\x12\n\x04tags\x18\x06 \x03(\tR\x04tags\x12-\n\x12resources_external\x18\x07 \x03(\tR\x11resourcesExternal\x12\x12\n\x04name\x18\x08 \x01(\tR\x04name\x12\x1d\n\x07version\x18\t \x01(\tH\x04R\x07version\x88\x01\x01\x12O\n\x14rendering_components\x18\n \x01(\x0b\x32\x17.google.protobuf.StructH\x05R\x13renderingComponents\x88\x01\x01\x12\x15\n\x03iri\x18\x0b \x01(\tH\x06R\x03iri\x88\x01\x01\x12\x36\n\x07\x63\x61ption\x18\x0c \x01(\x0b\x32\x17.google.protobuf.StructH\x07R\x07\x63\x61ption\x88\x01\x01\x12!\n\tthumbnail\x18\r \x01(\tH\x08R\tthumbnail\x88\x01\x01\x12\x19\n\x05image\x18\x0e \x01(\tH\tR\x05image\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x0f \x01(\tH\nR\x0b\x64\x65scription\x88\x01\x01\x12.\n\x10\x64\x61tetime_created\x18\x10 \x01(\tH\x0bR\x0f\x64\x61tetimeCreated\x88\x01\x01\x12\x39\n\x16\x64\x61tetime_last_modified\x18\x11 \x01(\tH\x0cR\x14\x64\x61tetimeLastModified\x88\x01\x01\x12&\n\x0cname_display\x18\x12 \x01(\tH\rR\x0bnameDisplay\x88\x01\x01\x12\x19\n\x05order\x18\x13 \x01(\x05H\x0eR\x05order\x88\x01\x01\x12(\n\rsearch_vector\x18\x14 \x01(\tH\x0fR\x0csearchVector\x88\x01\x01\x42\x13\n\x11_visualisation_idB\x0c\n\n_data_typeB\x1b\n\x19_plotting_method_instanceB\x1e\n\x1c_plotting_procedure_instanceB\n\n\x08_versionB\x17\n\x15_rendering_componentsB\x06\n\x04_iriB\n\n\x08_captionB\x0c\n\n_thumbnailB\x08\n\x06_imageB\x0e\n\x0c_descriptionB\x13\n\x11_datetime_createdB\x19\n\x17_datetime_last_modifiedB\x0f\n\r_name_displayB\x08\n\x06_orderB\x10\n\x0e_search_vector\"_\n$VisualisationRetrieveByNameNSRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12#\n\rnamespace_uri\x18\x02 \x01(\tR\x0cnamespaceUri\"I\n\x1cVisualisationRetrieveRequest\x12)\n\x10visualisation_id\x18\x01 \x01(\tR\x0fvisualisationId2\xb8\n\n\x0e\x44\x61taController\x12\x61\n\x06\x43reate\x12).lara_django.lara_django_data.DataRequest\x1a*.lara_django.lara_django_data.DataResponse\"\x00\x12U\n\x07\x44\x65stroy\x12\x30.lara_django.lara_django_data.DataDestroyRequest\x1a\x16.google.protobuf.Empty\"\x00\x12s\n\x0c\x44ownloadFile\x12..lara_django.lara_django_data.FileDownloadInfo\x1a/.lara_django.lara_django_data.FileDownloadChunk\"\x00\x30\x01\x12v\n\rDownloadImage\x12/.lara_django.lara_django_data.ImageDownloadInfo\x1a\x30.lara_django.lara_django_data.ImageDownloadChunk\"\x00\x30\x01\x12g\n\x04List\x12-.lara_django.lara_django_data.DataListRequest\x1a..lara_django.lara_django_data.DataListResponse\"\x00\x12u\n\rPartialUpdate\x12\x36.lara_django.lara_django_data.DataPartialUpdateRequest\x1a*.lara_django.lara_django_data.DataResponse\"\x00\x12k\n\x08Retrieve\x12\x31.lara_django.lara_django_data.DataRetrieveRequest\x1a*.lara_django.lara_django_data.DataResponse\"\x00\x12\x82\x01\n\x17RetrieveByNameNamespace\x12\x39.lara_django.lara_django_data.DataRetrieveByNameNSRequest\x1a*.lara_django.lara_django_data.DataResponse\"\x00\x12i\n\x06Stream\x12/.lara_django.lara_django_data.DataStreamRequest\x1a*.lara_django.lara_django_data.DataResponse\"\x00\x30\x01\x12\x61\n\x06Update\x12).lara_django.lara_django_data.DataRequest\x1a*.lara_django.lara_django_data.DataResponse\"\x00\x12m\n\nUploadFile\x12-.lara_django.lara_django_data.FileUploadChunk\x1a,.lara_django.lara_django_data.FileUploadInfo\"\x00(\x01\x12p\n\x0bUploadImage\x12..lara_django.lara_django_data.ImageUploadChunk\x1a-.lara_django.lara_django_data.ImageUploadInfo\"\x00(\x01\x32\xba\x06\n\x14\x44\x61taSubsetController\x12m\n\x06\x43reate\x12/.lara_django.lara_django_data.DataSubsetRequest\x1a\x30.lara_django.lara_django_data.DataSubsetResponse\"\x00\x12[\n\x07\x44\x65stroy\x12\x36.lara_django.lara_django_data.DataSubsetDestroyRequest\x1a\x16.google.protobuf.Empty\"\x00\x12s\n\x04List\x12\x33.lara_django.lara_django_data.DataSubsetListRequest\x1a\x34.lara_django.lara_django_data.DataSubsetListResponse\"\x00\x12\x81\x01\n\rPartialUpdate\x12<.lara_django.lara_django_data.DataSubsetPartialUpdateRequest\x1a\x30.lara_django.lara_django_data.DataSubsetResponse\"\x00\x12w\n\x08Retrieve\x12\x37.lara_django.lara_django_data.DataSubsetRetrieveRequest\x1a\x30.lara_django.lara_django_data.DataSubsetResponse\"\x00\x12u\n\x06Stream\x12\x35.lara_django.lara_django_data.DataSubsetStreamRequest\x1a\x30.lara_django.lara_django_data.DataSubsetResponse\"\x00\x30\x01\x12m\n\x06Update\x12/.lara_django.lara_django_data.DataSubsetRequest\x1a\x30.lara_django.lara_django_data.DataSubsetResponse\"\x00\x32\x99\x0b\n\x14\x45valuationController\x12m\n\x06\x43reate\x12/.lara_django.lara_django_data.EvaluationRequest\x1a\x30.lara_django.lara_django_data.EvaluationResponse\"\x00\x12[\n\x07\x44\x65stroy\x12\x36.lara_django.lara_django_data.EvaluationDestroyRequest\x1a\x16.google.protobuf.Empty\"\x00\x12s\n\x0c\x44ownloadFile\x12..lara_django.lara_django_data.FileDownloadInfo\x1a/.lara_django.lara_django_data.FileDownloadChunk\"\x00\x30\x01\x12v\n\rDownloadImage\x12/.lara_django.lara_django_data.ImageDownloadInfo\x1a\x30.lara_django.lara_django_data.ImageDownloadChunk\"\x00\x30\x01\x12s\n\x04List\x12\x33.lara_django.lara_django_data.EvaluationListRequest\x1a\x34.lara_django.lara_django_data.EvaluationListResponse\"\x00\x12\x81\x01\n\rPartialUpdate\x12<.lara_django.lara_django_data.EvaluationPartialUpdateRequest\x1a\x30.lara_django.lara_django_data.EvaluationResponse\"\x00\x12w\n\x08Retrieve\x12\x37.lara_django.lara_django_data.EvaluationRetrieveRequest\x1a\x30.lara_django.lara_django_data.EvaluationResponse\"\x00\x12\x8e\x01\n\x17RetrieveByNameNamespace\x12?.lara_django.lara_django_data.EvaluationRetrieveByNameNSRequest\x1a\x30.lara_django.lara_django_data.EvaluationResponse\"\x00\x12u\n\x06Stream\x12\x35.lara_django.lara_django_data.EvaluationStreamRequest\x1a\x30.lara_django.lara_django_data.EvaluationResponse\"\x00\x30\x01\x12m\n\x06Update\x12/.lara_django.lara_django_data.EvaluationRequest\x1a\x30.lara_django.lara_django_data.EvaluationResponse\"\x00\x12m\n\nUploadFile\x12-.lara_django.lara_django_data.FileUploadChunk\x1a,.lara_django.lara_django_data.FileUploadInfo\"\x00(\x01\x12p\n\x0bUploadImage\x12..lara_django.lara_django_data.ImageUploadChunk\x1a-.lara_django.lara_django_data.ImageUploadInfo\"\x00(\x01\x32\xab\x06\n\x13\x45xtraDataController\x12k\n\x06\x43reate\x12..lara_django.lara_django_data.ExtraDataRequest\x1a/.lara_django.lara_django_data.ExtraDataResponse\"\x00\x12Z\n\x07\x44\x65stroy\x12\x35.lara_django.lara_django_data.ExtraDataDestroyRequest\x1a\x16.google.protobuf.Empty\"\x00\x12q\n\x04List\x12\x32.lara_django.lara_django_data.ExtraDataListRequest\x1a\x33.lara_django.lara_django_data.ExtraDataListResponse\"\x00\x12\x7f\n\rPartialUpdate\x12;.lara_django.lara_django_data.ExtraDataPartialUpdateRequest\x1a/.lara_django.lara_django_data.ExtraDataResponse\"\x00\x12u\n\x08Retrieve\x12\x36.lara_django.lara_django_data.ExtraDataRetrieveRequest\x1a/.lara_django.lara_django_data.ExtraDataResponse\"\x00\x12s\n\x06Stream\x12\x34.lara_django.lara_django_data.ExtraDataStreamRequest\x1a/.lara_django.lara_django_data.ExtraDataResponse\"\x00\x30\x01\x12k\n\x06Update\x12..lara_django.lara_django_data.ExtraDataRequest\x1a/.lara_django.lara_django_data.ExtraDataResponse\"\x00\x32\xcc\n\n\x17VisualisationController\x12s\n\x06\x43reate\x12\x32.lara_django.lara_django_data.VisualisationRequest\x1a\x33.lara_django.lara_django_data.VisualisationResponse\"\x00\x12^\n\x07\x44\x65stroy\x12\x39.lara_django.lara_django_data.VisualisationDestroyRequest\x1a\x16.google.protobuf.Empty\"\x00\x12s\n\x0c\x44ownloadFile\x12..lara_django.lara_django_data.FileDownloadInfo\x1a/.lara_django.lara_django_data.FileDownloadChunk\"\x00\x30\x01\x12v\n\rDownloadImage\x12/.lara_django.lara_django_data.ImageDownloadInfo\x1a\x30.lara_django.lara_django_data.ImageDownloadChunk\"\x00\x30\x01\x12y\n\x04List\x12\x36.lara_django.lara_django_data.VisualisationListRequest\x1a\x37.lara_django.lara_django_data.VisualisationListResponse\"\x00\x12\x87\x01\n\rPartialUpdate\x12?.lara_django.lara_django_data.VisualisationPartialUpdateRequest\x1a\x33.lara_django.lara_django_data.VisualisationResponse\"\x00\x12}\n\x08Retrieve\x12:.lara_django.lara_django_data.VisualisationRetrieveRequest\x1a\x33.lara_django.lara_django_data.VisualisationResponse\"\x00\x12\x94\x01\n\x17RetrieveByNameNamespace\x12\x42.lara_django.lara_django_data.VisualisationRetrieveByNameNSRequest\x1a\x33.lara_django.lara_django_data.VisualisationResponse\"\x00\x12s\n\x06Update\x12\x32.lara_django.lara_django_data.VisualisationRequest\x1a\x33.lara_django.lara_django_data.VisualisationResponse\"\x00\x12m\n\nUploadFile\x12-.lara_django.lara_django_data.FileUploadChunk\x1a,.lara_django.lara_django_data.FileUploadInfo\"\x00(\x01\x12p\n\x0bUploadImage\x12..lara_django.lara_django_data.ImageUploadChunk\x1a-.lara_django.lara_django_data.ImageUploadInfo\"\x00(\x01\x42\x81\x02\n com.lara_django.lara_django_dataB\x13LaraDjangoDataProtoP\x01ZCgitlab.com/larasuite/lara-django-data/grpc/lara_django_data_grpc/v1\xa2\x02\x03LLX\xaa\x02\x19LaraDjango.LaraDjangoData\xca\x02\x19LaraDjango\\LaraDjangoData\xe2\x02%LaraDjango\\LaraDjangoData\\GPBMetadata\xea\x02\x1aLaraDjango::LaraDjangoDatab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'lara_django_data_grpc.v1.lara_django_data_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n com.lara_django.lara_django_dataB\023LaraDjangoDataProtoP\001ZCgitlab.com/larasuite/lara-django-data/grpc/lara_django_data_grpc/v1\242\002\003LLX\252\002\031LaraDjango.LaraDjangoData\312\002\031LaraDjango\\LaraDjangoData\342\002%LaraDjango\\LaraDjangoData\\GPBMetadata\352\002\032LaraDjango::LaraDjangoData'
  _globals['_DATADESTROYREQUEST']._serialized_start=140
  _globals['_DATADESTROYREQUEST']._serialized_end=185
  _globals['_DATALISTREQUEST']._serialized_start=187
  _globals['_DATALISTREQUEST']._serialized_end=204
  _globals['_DATALISTRESPONSE']._serialized_start=206
  _globals['_DATALISTRESPONSE']._serialized_end=294
  _globals['_DATAPARTIALUPDATEREQUEST']._serialized_start=297
  _globals['_DATAPARTIALUPDATEREQUEST']._serialized_end=2042
  _globals['_DATAREQUEST']._serialized_start=2045
  _globals['_DATAREQUEST']._serialized_end=3724
  _globals['_DATARESPONSE']._serialized_start=3727
  _globals['_DATARESPONSE']._serialized_end=5407
  _globals['_DATARETRIEVEBYNAMENSREQUEST']._serialized_start=5409
  _globals['_DATARETRIEVEBYNAMENSREQUEST']._serialized_end=5495
  _globals['_DATARETRIEVEREQUEST']._serialized_start=5497
  _globals['_DATARETRIEVEREQUEST']._serialized_end=5543
  _globals['_DATASTREAMREQUEST']._serialized_start=5545
  _globals['_DATASTREAMREQUEST']._serialized_end=5564
  _globals['_DATASUBSETDESTROYREQUEST']._serialized_start=5566
  _globals['_DATASUBSETDESTROYREQUEST']._serialized_end=5629
  _globals['_DATASUBSETLISTREQUEST']._serialized_start=5631
  _globals['_DATASUBSETLISTREQUEST']._serialized_end=5654
  _globals['_DATASUBSETLISTRESPONSE']._serialized_start=5656
  _globals['_DATASUBSETLISTRESPONSE']._serialized_end=5756
  _globals['_DATASUBSETPARTIALUPDATEREQUEST']._serialized_start=5759
  _globals['_DATASUBSETPARTIALUPDATEREQUEST']._serialized_end=6253
  _globals['_DATASUBSETREQUEST']._serialized_start=6256
  _globals['_DATASUBSETREQUEST']._serialized_end=6684
  _globals['_DATASUBSETRESPONSE']._serialized_start=6687
  _globals['_DATASUBSETRESPONSE']._serialized_end=7116
  _globals['_DATASUBSETRETRIEVEREQUEST']._serialized_start=7118
  _globals['_DATASUBSETRETRIEVEREQUEST']._serialized_end=7182
  _globals['_DATASUBSETSTREAMREQUEST']._serialized_start=7184
  _globals['_DATASUBSETSTREAMREQUEST']._serialized_end=7209
  _globals['_EVALUATIONDESTROYREQUEST']._serialized_start=7211
  _globals['_EVALUATIONDESTROYREQUEST']._serialized_end=7274
  _globals['_EVALUATIONLISTREQUEST']._serialized_start=7276
  _globals['_EVALUATIONLISTREQUEST']._serialized_end=7299
  _globals['_EVALUATIONLISTRESPONSE']._serialized_start=7301
  _globals['_EVALUATIONLISTRESPONSE']._serialized_end=7401
  _globals['_EVALUATIONPARTIALUPDATEREQUEST']._serialized_start=7404
  _globals['_EVALUATIONPARTIALUPDATEREQUEST']._serialized_end=8636
  _globals['_EVALUATIONREQUEST']._serialized_start=8639
  _globals['_EVALUATIONREQUEST']._serialized_end=9805
  _globals['_EVALUATIONRESPONSE']._serialized_start=9808
  _globals['_EVALUATIONRESPONSE']._serialized_end=10975
  _globals['_EVALUATIONRETRIEVEBYNAMENSREQUEST']._serialized_start=10977
  _globals['_EVALUATIONRETRIEVEBYNAMENSREQUEST']._serialized_end=11069
  _globals['_EVALUATIONRETRIEVEREQUEST']._serialized_start=11071
  _globals['_EVALUATIONRETRIEVEREQUEST']._serialized_end=11135
  _globals['_EVALUATIONSTREAMREQUEST']._serialized_start=11137
  _globals['_EVALUATIONSTREAMREQUEST']._serialized_end=11162
  _globals['_EXTRADATADESTROYREQUEST']._serialized_start=11164
  _globals['_EXTRADATADESTROYREQUEST']._serialized_end=11224
  _globals['_EXTRADATALISTREQUEST']._serialized_start=11226
  _globals['_EXTRADATALISTREQUEST']._serialized_end=11248
  _globals['_EXTRADATALISTRESPONSE']._serialized_start=11250
  _globals['_EXTRADATALISTRESPONSE']._serialized_end=11348
  _globals['_EXTRADATAPARTIALUPDATEREQUEST']._serialized_start=11351
  _globals['_EXTRADATAPARTIALUPDATEREQUEST']._serialized_end=12302
  _globals['_EXTRADATAREQUEST']._serialized_start=12305
  _globals['_EXTRADATAREQUEST']._serialized_end=13190
  _globals['_EXTRADATARESPONSE']._serialized_start=13193
  _globals['_EXTRADATARESPONSE']._serialized_end=14079
  _globals['_EXTRADATARETRIEVEREQUEST']._serialized_start=14081
  _globals['_EXTRADATARETRIEVEREQUEST']._serialized_end=14142
  _globals['_EXTRADATASTREAMREQUEST']._serialized_start=14144
  _globals['_EXTRADATASTREAMREQUEST']._serialized_end=14168
  _globals['_FILEDOWNLOADCHUNK']._serialized_start=14170
  _globals['_FILEDOWNLOADCHUNK']._serialized_end=14263
  _globals['_FILEDOWNLOADINFO']._serialized_start=14265
  _globals['_FILEDOWNLOADINFO']._serialized_end=14339
  _globals['_FILEUPLOADCHUNK']._serialized_start=14341
  _globals['_FILEUPLOADCHUNK']._serialized_end=14444
  _globals['_FILEUPLOADINFO']._serialized_start=14446
  _globals['_FILEUPLOADINFO']._serialized_end=14488
  _globals['_IMAGEDOWNLOADCHUNK']._serialized_start=14490
  _globals['_IMAGEDOWNLOADCHUNK']._serialized_end=14595
  _globals['_IMAGEDOWNLOADINFO']._serialized_start=14597
  _globals['_IMAGEDOWNLOADINFO']._serialized_end=14672
  _globals['_IMAGEUPLOADCHUNK']._serialized_start=14674
  _globals['_IMAGEUPLOADCHUNK']._serialized_end=14778
  _globals['_IMAGEUPLOADINFO']._serialized_start=14780
  _globals['_IMAGEUPLOADINFO']._serialized_end=14823
  _globals['_VISUALISATIONDESTROYREQUEST']._serialized_start=14825
  _globals['_VISUALISATIONDESTROYREQUEST']._serialized_end=14897
  _globals['_VISUALISATIONLISTREQUEST']._serialized_start=14899
  _globals['_VISUALISATIONLISTREQUEST']._serialized_end=14925
  _globals['_VISUALISATIONLISTRESPONSE']._serialized_start=14927
  _globals['_VISUALISATIONLISTRESPONSE']._serialized_end=15033
  _globals['_VISUALISATIONPARTIALUPDATEREQUEST']._serialized_start=15036
  _globals['_VISUALISATIONPARTIALUPDATEREQUEST']._serialized_end=16249
  _globals['_VISUALISATIONREQUEST']._serialized_start=16252
  _globals['_VISUALISATIONREQUEST']._serialized_end=17399
  _globals['_VISUALISATIONRESPONSE']._serialized_start=17402
  _globals['_VISUALISATIONRESPONSE']._serialized_end=18550
  _globals['_VISUALISATIONRETRIEVEBYNAMENSREQUEST']._serialized_start=18552
  _globals['_VISUALISATIONRETRIEVEBYNAMENSREQUEST']._serialized_end=18647
  _globals['_VISUALISATIONRETRIEVEREQUEST']._serialized_start=18649
  _globals['_VISUALISATIONRETRIEVEREQUEST']._serialized_end=18722
  _globals['_DATACONTROLLER']._serialized_start=18725
  _globals['_DATACONTROLLER']._serialized_end=20061
  _globals['_DATASUBSETCONTROLLER']._serialized_start=20064
  _globals['_DATASUBSETCONTROLLER']._serialized_end=20890
  _globals['_EVALUATIONCONTROLLER']._serialized_start=20893
  _globals['_EVALUATIONCONTROLLER']._serialized_end=22326
  _globals['_EXTRADATACONTROLLER']._serialized_start=22329
  _globals['_EXTRADATACONTROLLER']._serialized_end=23140
  _globals['_VISUALISATIONCONTROLLER']._serialized_start=23143
  _globals['_VISUALISATIONCONTROLLER']._serialized_end=24499
# @@protoc_insertion_point(module_scope)
