# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from lara_django_data_grpc.v1 import lara_django_data_pb2 as lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2


class DataControllerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Create = channel.unary_unary(
                '/lara_django.lara_django_data.DataController/Create',
                request_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataRequest.SerializeToString,
                response_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataResponse.FromString,
                _registered_method=True)
        self.Destroy = channel.unary_unary(
                '/lara_django.lara_django_data.DataController/Destroy',
                request_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataDestroyRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)
        self.DownloadFile = channel.unary_stream(
                '/lara_django.lara_django_data.DataController/DownloadFile',
                request_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.FileDownloadInfo.SerializeToString,
                response_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.FileDownloadChunk.FromString,
                _registered_method=True)
        self.DownloadImage = channel.unary_stream(
                '/lara_django.lara_django_data.DataController/DownloadImage',
                request_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ImageDownloadInfo.SerializeToString,
                response_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ImageDownloadChunk.FromString,
                _registered_method=True)
        self.List = channel.unary_unary(
                '/lara_django.lara_django_data.DataController/List',
                request_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataListRequest.SerializeToString,
                response_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataListResponse.FromString,
                _registered_method=True)
        self.PartialUpdate = channel.unary_unary(
                '/lara_django.lara_django_data.DataController/PartialUpdate',
                request_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataPartialUpdateRequest.SerializeToString,
                response_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataResponse.FromString,
                _registered_method=True)
        self.Retrieve = channel.unary_unary(
                '/lara_django.lara_django_data.DataController/Retrieve',
                request_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataRetrieveRequest.SerializeToString,
                response_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataResponse.FromString,
                _registered_method=True)
        self.RetrieveByNameNamespace = channel.unary_unary(
                '/lara_django.lara_django_data.DataController/RetrieveByNameNamespace',
                request_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataRetrieveByNameNSRequest.SerializeToString,
                response_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataResponse.FromString,
                _registered_method=True)
        self.Stream = channel.unary_stream(
                '/lara_django.lara_django_data.DataController/Stream',
                request_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataStreamRequest.SerializeToString,
                response_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataResponse.FromString,
                _registered_method=True)
        self.Update = channel.unary_unary(
                '/lara_django.lara_django_data.DataController/Update',
                request_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataRequest.SerializeToString,
                response_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataResponse.FromString,
                _registered_method=True)
        self.UploadFile = channel.stream_unary(
                '/lara_django.lara_django_data.DataController/UploadFile',
                request_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.FileUploadChunk.SerializeToString,
                response_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.FileUploadInfo.FromString,
                _registered_method=True)
        self.UploadImage = channel.stream_unary(
                '/lara_django.lara_django_data.DataController/UploadImage',
                request_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ImageUploadChunk.SerializeToString,
                response_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ImageUploadInfo.FromString,
                _registered_method=True)


class DataControllerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Create(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Destroy(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DownloadFile(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DownloadImage(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PartialUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Retrieve(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RetrieveByNameNamespace(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Stream(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UploadFile(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UploadImage(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DataControllerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataRequest.FromString,
                    response_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataResponse.SerializeToString,
            ),
            'Destroy': grpc.unary_unary_rpc_method_handler(
                    servicer.Destroy,
                    request_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataDestroyRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'DownloadFile': grpc.unary_stream_rpc_method_handler(
                    servicer.DownloadFile,
                    request_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.FileDownloadInfo.FromString,
                    response_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.FileDownloadChunk.SerializeToString,
            ),
            'DownloadImage': grpc.unary_stream_rpc_method_handler(
                    servicer.DownloadImage,
                    request_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ImageDownloadInfo.FromString,
                    response_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ImageDownloadChunk.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataListRequest.FromString,
                    response_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataListResponse.SerializeToString,
            ),
            'PartialUpdate': grpc.unary_unary_rpc_method_handler(
                    servicer.PartialUpdate,
                    request_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataPartialUpdateRequest.FromString,
                    response_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataResponse.SerializeToString,
            ),
            'Retrieve': grpc.unary_unary_rpc_method_handler(
                    servicer.Retrieve,
                    request_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataRetrieveRequest.FromString,
                    response_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataResponse.SerializeToString,
            ),
            'RetrieveByNameNamespace': grpc.unary_unary_rpc_method_handler(
                    servicer.RetrieveByNameNamespace,
                    request_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataRetrieveByNameNSRequest.FromString,
                    response_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataResponse.SerializeToString,
            ),
            'Stream': grpc.unary_stream_rpc_method_handler(
                    servicer.Stream,
                    request_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataStreamRequest.FromString,
                    response_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataResponse.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataRequest.FromString,
                    response_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataResponse.SerializeToString,
            ),
            'UploadFile': grpc.stream_unary_rpc_method_handler(
                    servicer.UploadFile,
                    request_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.FileUploadChunk.FromString,
                    response_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.FileUploadInfo.SerializeToString,
            ),
            'UploadImage': grpc.stream_unary_rpc_method_handler(
                    servicer.UploadImage,
                    request_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ImageUploadChunk.FromString,
                    response_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ImageUploadInfo.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'lara_django.lara_django_data.DataController', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('lara_django.lara_django_data.DataController', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class DataController(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_data.DataController/Create',
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataRequest.SerializeToString,
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Destroy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_data.DataController/Destroy',
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataDestroyRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DownloadFile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/lara_django.lara_django_data.DataController/DownloadFile',
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.FileDownloadInfo.SerializeToString,
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.FileDownloadChunk.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DownloadImage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/lara_django.lara_django_data.DataController/DownloadImage',
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ImageDownloadInfo.SerializeToString,
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ImageDownloadChunk.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_data.DataController/List',
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataListRequest.SerializeToString,
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataListResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def PartialUpdate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_data.DataController/PartialUpdate',
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataPartialUpdateRequest.SerializeToString,
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Retrieve(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_data.DataController/Retrieve',
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataRetrieveRequest.SerializeToString,
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RetrieveByNameNamespace(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_data.DataController/RetrieveByNameNamespace',
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataRetrieveByNameNSRequest.SerializeToString,
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Stream(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/lara_django.lara_django_data.DataController/Stream',
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataStreamRequest.SerializeToString,
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_data.DataController/Update',
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataRequest.SerializeToString,
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UploadFile(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(
            request_iterator,
            target,
            '/lara_django.lara_django_data.DataController/UploadFile',
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.FileUploadChunk.SerializeToString,
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.FileUploadInfo.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UploadImage(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(
            request_iterator,
            target,
            '/lara_django.lara_django_data.DataController/UploadImage',
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ImageUploadChunk.SerializeToString,
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ImageUploadInfo.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)


class DataSubsetControllerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Create = channel.unary_unary(
                '/lara_django.lara_django_data.DataSubsetController/Create',
                request_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataSubsetRequest.SerializeToString,
                response_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataSubsetResponse.FromString,
                _registered_method=True)
        self.Destroy = channel.unary_unary(
                '/lara_django.lara_django_data.DataSubsetController/Destroy',
                request_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataSubsetDestroyRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)
        self.List = channel.unary_unary(
                '/lara_django.lara_django_data.DataSubsetController/List',
                request_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataSubsetListRequest.SerializeToString,
                response_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataSubsetListResponse.FromString,
                _registered_method=True)
        self.PartialUpdate = channel.unary_unary(
                '/lara_django.lara_django_data.DataSubsetController/PartialUpdate',
                request_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataSubsetPartialUpdateRequest.SerializeToString,
                response_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataSubsetResponse.FromString,
                _registered_method=True)
        self.Retrieve = channel.unary_unary(
                '/lara_django.lara_django_data.DataSubsetController/Retrieve',
                request_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataSubsetRetrieveRequest.SerializeToString,
                response_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataSubsetResponse.FromString,
                _registered_method=True)
        self.Stream = channel.unary_stream(
                '/lara_django.lara_django_data.DataSubsetController/Stream',
                request_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataSubsetStreamRequest.SerializeToString,
                response_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataSubsetResponse.FromString,
                _registered_method=True)
        self.Update = channel.unary_unary(
                '/lara_django.lara_django_data.DataSubsetController/Update',
                request_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataSubsetRequest.SerializeToString,
                response_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataSubsetResponse.FromString,
                _registered_method=True)


class DataSubsetControllerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Create(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Destroy(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PartialUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Retrieve(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Stream(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DataSubsetControllerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataSubsetRequest.FromString,
                    response_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataSubsetResponse.SerializeToString,
            ),
            'Destroy': grpc.unary_unary_rpc_method_handler(
                    servicer.Destroy,
                    request_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataSubsetDestroyRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataSubsetListRequest.FromString,
                    response_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataSubsetListResponse.SerializeToString,
            ),
            'PartialUpdate': grpc.unary_unary_rpc_method_handler(
                    servicer.PartialUpdate,
                    request_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataSubsetPartialUpdateRequest.FromString,
                    response_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataSubsetResponse.SerializeToString,
            ),
            'Retrieve': grpc.unary_unary_rpc_method_handler(
                    servicer.Retrieve,
                    request_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataSubsetRetrieveRequest.FromString,
                    response_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataSubsetResponse.SerializeToString,
            ),
            'Stream': grpc.unary_stream_rpc_method_handler(
                    servicer.Stream,
                    request_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataSubsetStreamRequest.FromString,
                    response_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataSubsetResponse.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataSubsetRequest.FromString,
                    response_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataSubsetResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'lara_django.lara_django_data.DataSubsetController', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('lara_django.lara_django_data.DataSubsetController', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class DataSubsetController(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_data.DataSubsetController/Create',
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataSubsetRequest.SerializeToString,
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataSubsetResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Destroy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_data.DataSubsetController/Destroy',
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataSubsetDestroyRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_data.DataSubsetController/List',
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataSubsetListRequest.SerializeToString,
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataSubsetListResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def PartialUpdate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_data.DataSubsetController/PartialUpdate',
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataSubsetPartialUpdateRequest.SerializeToString,
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataSubsetResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Retrieve(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_data.DataSubsetController/Retrieve',
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataSubsetRetrieveRequest.SerializeToString,
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataSubsetResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Stream(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/lara_django.lara_django_data.DataSubsetController/Stream',
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataSubsetStreamRequest.SerializeToString,
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataSubsetResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_data.DataSubsetController/Update',
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataSubsetRequest.SerializeToString,
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.DataSubsetResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)


class EvaluationControllerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Create = channel.unary_unary(
                '/lara_django.lara_django_data.EvaluationController/Create',
                request_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.EvaluationRequest.SerializeToString,
                response_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.EvaluationResponse.FromString,
                _registered_method=True)
        self.Destroy = channel.unary_unary(
                '/lara_django.lara_django_data.EvaluationController/Destroy',
                request_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.EvaluationDestroyRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)
        self.DownloadFile = channel.unary_stream(
                '/lara_django.lara_django_data.EvaluationController/DownloadFile',
                request_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.FileDownloadInfo.SerializeToString,
                response_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.FileDownloadChunk.FromString,
                _registered_method=True)
        self.DownloadImage = channel.unary_stream(
                '/lara_django.lara_django_data.EvaluationController/DownloadImage',
                request_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ImageDownloadInfo.SerializeToString,
                response_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ImageDownloadChunk.FromString,
                _registered_method=True)
        self.List = channel.unary_unary(
                '/lara_django.lara_django_data.EvaluationController/List',
                request_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.EvaluationListRequest.SerializeToString,
                response_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.EvaluationListResponse.FromString,
                _registered_method=True)
        self.PartialUpdate = channel.unary_unary(
                '/lara_django.lara_django_data.EvaluationController/PartialUpdate',
                request_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.EvaluationPartialUpdateRequest.SerializeToString,
                response_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.EvaluationResponse.FromString,
                _registered_method=True)
        self.Retrieve = channel.unary_unary(
                '/lara_django.lara_django_data.EvaluationController/Retrieve',
                request_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.EvaluationRetrieveRequest.SerializeToString,
                response_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.EvaluationResponse.FromString,
                _registered_method=True)
        self.RetrieveByNameNamespace = channel.unary_unary(
                '/lara_django.lara_django_data.EvaluationController/RetrieveByNameNamespace',
                request_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.EvaluationRetrieveByNameNSRequest.SerializeToString,
                response_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.EvaluationResponse.FromString,
                _registered_method=True)
        self.Stream = channel.unary_stream(
                '/lara_django.lara_django_data.EvaluationController/Stream',
                request_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.EvaluationStreamRequest.SerializeToString,
                response_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.EvaluationResponse.FromString,
                _registered_method=True)
        self.Update = channel.unary_unary(
                '/lara_django.lara_django_data.EvaluationController/Update',
                request_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.EvaluationRequest.SerializeToString,
                response_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.EvaluationResponse.FromString,
                _registered_method=True)
        self.UploadFile = channel.stream_unary(
                '/lara_django.lara_django_data.EvaluationController/UploadFile',
                request_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.FileUploadChunk.SerializeToString,
                response_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.FileUploadInfo.FromString,
                _registered_method=True)
        self.UploadImage = channel.stream_unary(
                '/lara_django.lara_django_data.EvaluationController/UploadImage',
                request_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ImageUploadChunk.SerializeToString,
                response_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ImageUploadInfo.FromString,
                _registered_method=True)


class EvaluationControllerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Create(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Destroy(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DownloadFile(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DownloadImage(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PartialUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Retrieve(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RetrieveByNameNamespace(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Stream(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UploadFile(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UploadImage(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_EvaluationControllerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.EvaluationRequest.FromString,
                    response_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.EvaluationResponse.SerializeToString,
            ),
            'Destroy': grpc.unary_unary_rpc_method_handler(
                    servicer.Destroy,
                    request_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.EvaluationDestroyRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'DownloadFile': grpc.unary_stream_rpc_method_handler(
                    servicer.DownloadFile,
                    request_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.FileDownloadInfo.FromString,
                    response_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.FileDownloadChunk.SerializeToString,
            ),
            'DownloadImage': grpc.unary_stream_rpc_method_handler(
                    servicer.DownloadImage,
                    request_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ImageDownloadInfo.FromString,
                    response_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ImageDownloadChunk.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.EvaluationListRequest.FromString,
                    response_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.EvaluationListResponse.SerializeToString,
            ),
            'PartialUpdate': grpc.unary_unary_rpc_method_handler(
                    servicer.PartialUpdate,
                    request_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.EvaluationPartialUpdateRequest.FromString,
                    response_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.EvaluationResponse.SerializeToString,
            ),
            'Retrieve': grpc.unary_unary_rpc_method_handler(
                    servicer.Retrieve,
                    request_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.EvaluationRetrieveRequest.FromString,
                    response_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.EvaluationResponse.SerializeToString,
            ),
            'RetrieveByNameNamespace': grpc.unary_unary_rpc_method_handler(
                    servicer.RetrieveByNameNamespace,
                    request_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.EvaluationRetrieveByNameNSRequest.FromString,
                    response_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.EvaluationResponse.SerializeToString,
            ),
            'Stream': grpc.unary_stream_rpc_method_handler(
                    servicer.Stream,
                    request_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.EvaluationStreamRequest.FromString,
                    response_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.EvaluationResponse.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.EvaluationRequest.FromString,
                    response_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.EvaluationResponse.SerializeToString,
            ),
            'UploadFile': grpc.stream_unary_rpc_method_handler(
                    servicer.UploadFile,
                    request_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.FileUploadChunk.FromString,
                    response_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.FileUploadInfo.SerializeToString,
            ),
            'UploadImage': grpc.stream_unary_rpc_method_handler(
                    servicer.UploadImage,
                    request_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ImageUploadChunk.FromString,
                    response_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ImageUploadInfo.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'lara_django.lara_django_data.EvaluationController', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('lara_django.lara_django_data.EvaluationController', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class EvaluationController(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_data.EvaluationController/Create',
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.EvaluationRequest.SerializeToString,
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.EvaluationResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Destroy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_data.EvaluationController/Destroy',
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.EvaluationDestroyRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DownloadFile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/lara_django.lara_django_data.EvaluationController/DownloadFile',
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.FileDownloadInfo.SerializeToString,
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.FileDownloadChunk.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DownloadImage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/lara_django.lara_django_data.EvaluationController/DownloadImage',
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ImageDownloadInfo.SerializeToString,
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ImageDownloadChunk.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_data.EvaluationController/List',
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.EvaluationListRequest.SerializeToString,
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.EvaluationListResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def PartialUpdate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_data.EvaluationController/PartialUpdate',
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.EvaluationPartialUpdateRequest.SerializeToString,
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.EvaluationResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Retrieve(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_data.EvaluationController/Retrieve',
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.EvaluationRetrieveRequest.SerializeToString,
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.EvaluationResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RetrieveByNameNamespace(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_data.EvaluationController/RetrieveByNameNamespace',
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.EvaluationRetrieveByNameNSRequest.SerializeToString,
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.EvaluationResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Stream(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/lara_django.lara_django_data.EvaluationController/Stream',
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.EvaluationStreamRequest.SerializeToString,
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.EvaluationResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_data.EvaluationController/Update',
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.EvaluationRequest.SerializeToString,
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.EvaluationResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UploadFile(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(
            request_iterator,
            target,
            '/lara_django.lara_django_data.EvaluationController/UploadFile',
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.FileUploadChunk.SerializeToString,
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.FileUploadInfo.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UploadImage(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(
            request_iterator,
            target,
            '/lara_django.lara_django_data.EvaluationController/UploadImage',
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ImageUploadChunk.SerializeToString,
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ImageUploadInfo.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)


class ExtraDataControllerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Create = channel.unary_unary(
                '/lara_django.lara_django_data.ExtraDataController/Create',
                request_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ExtraDataRequest.SerializeToString,
                response_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ExtraDataResponse.FromString,
                _registered_method=True)
        self.Destroy = channel.unary_unary(
                '/lara_django.lara_django_data.ExtraDataController/Destroy',
                request_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ExtraDataDestroyRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)
        self.List = channel.unary_unary(
                '/lara_django.lara_django_data.ExtraDataController/List',
                request_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ExtraDataListRequest.SerializeToString,
                response_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ExtraDataListResponse.FromString,
                _registered_method=True)
        self.PartialUpdate = channel.unary_unary(
                '/lara_django.lara_django_data.ExtraDataController/PartialUpdate',
                request_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ExtraDataPartialUpdateRequest.SerializeToString,
                response_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ExtraDataResponse.FromString,
                _registered_method=True)
        self.Retrieve = channel.unary_unary(
                '/lara_django.lara_django_data.ExtraDataController/Retrieve',
                request_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ExtraDataRetrieveRequest.SerializeToString,
                response_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ExtraDataResponse.FromString,
                _registered_method=True)
        self.Stream = channel.unary_stream(
                '/lara_django.lara_django_data.ExtraDataController/Stream',
                request_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ExtraDataStreamRequest.SerializeToString,
                response_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ExtraDataResponse.FromString,
                _registered_method=True)
        self.Update = channel.unary_unary(
                '/lara_django.lara_django_data.ExtraDataController/Update',
                request_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ExtraDataRequest.SerializeToString,
                response_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ExtraDataResponse.FromString,
                _registered_method=True)


class ExtraDataControllerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Create(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Destroy(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PartialUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Retrieve(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Stream(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ExtraDataControllerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ExtraDataRequest.FromString,
                    response_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ExtraDataResponse.SerializeToString,
            ),
            'Destroy': grpc.unary_unary_rpc_method_handler(
                    servicer.Destroy,
                    request_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ExtraDataDestroyRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ExtraDataListRequest.FromString,
                    response_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ExtraDataListResponse.SerializeToString,
            ),
            'PartialUpdate': grpc.unary_unary_rpc_method_handler(
                    servicer.PartialUpdate,
                    request_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ExtraDataPartialUpdateRequest.FromString,
                    response_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ExtraDataResponse.SerializeToString,
            ),
            'Retrieve': grpc.unary_unary_rpc_method_handler(
                    servicer.Retrieve,
                    request_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ExtraDataRetrieveRequest.FromString,
                    response_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ExtraDataResponse.SerializeToString,
            ),
            'Stream': grpc.unary_stream_rpc_method_handler(
                    servicer.Stream,
                    request_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ExtraDataStreamRequest.FromString,
                    response_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ExtraDataResponse.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ExtraDataRequest.FromString,
                    response_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ExtraDataResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'lara_django.lara_django_data.ExtraDataController', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('lara_django.lara_django_data.ExtraDataController', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class ExtraDataController(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_data.ExtraDataController/Create',
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ExtraDataRequest.SerializeToString,
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ExtraDataResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Destroy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_data.ExtraDataController/Destroy',
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ExtraDataDestroyRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_data.ExtraDataController/List',
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ExtraDataListRequest.SerializeToString,
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ExtraDataListResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def PartialUpdate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_data.ExtraDataController/PartialUpdate',
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ExtraDataPartialUpdateRequest.SerializeToString,
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ExtraDataResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Retrieve(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_data.ExtraDataController/Retrieve',
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ExtraDataRetrieveRequest.SerializeToString,
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ExtraDataResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Stream(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/lara_django.lara_django_data.ExtraDataController/Stream',
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ExtraDataStreamRequest.SerializeToString,
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ExtraDataResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_data.ExtraDataController/Update',
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ExtraDataRequest.SerializeToString,
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ExtraDataResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)


class VisualisationControllerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Create = channel.unary_unary(
                '/lara_django.lara_django_data.VisualisationController/Create',
                request_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.VisualisationRequest.SerializeToString,
                response_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.VisualisationResponse.FromString,
                _registered_method=True)
        self.Destroy = channel.unary_unary(
                '/lara_django.lara_django_data.VisualisationController/Destroy',
                request_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.VisualisationDestroyRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)
        self.DownloadFile = channel.unary_stream(
                '/lara_django.lara_django_data.VisualisationController/DownloadFile',
                request_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.FileDownloadInfo.SerializeToString,
                response_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.FileDownloadChunk.FromString,
                _registered_method=True)
        self.DownloadImage = channel.unary_stream(
                '/lara_django.lara_django_data.VisualisationController/DownloadImage',
                request_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ImageDownloadInfo.SerializeToString,
                response_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ImageDownloadChunk.FromString,
                _registered_method=True)
        self.List = channel.unary_unary(
                '/lara_django.lara_django_data.VisualisationController/List',
                request_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.VisualisationListRequest.SerializeToString,
                response_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.VisualisationListResponse.FromString,
                _registered_method=True)
        self.PartialUpdate = channel.unary_unary(
                '/lara_django.lara_django_data.VisualisationController/PartialUpdate',
                request_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.VisualisationPartialUpdateRequest.SerializeToString,
                response_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.VisualisationResponse.FromString,
                _registered_method=True)
        self.Retrieve = channel.unary_unary(
                '/lara_django.lara_django_data.VisualisationController/Retrieve',
                request_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.VisualisationRetrieveRequest.SerializeToString,
                response_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.VisualisationResponse.FromString,
                _registered_method=True)
        self.RetrieveByNameNamespace = channel.unary_unary(
                '/lara_django.lara_django_data.VisualisationController/RetrieveByNameNamespace',
                request_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.VisualisationRetrieveByNameNSRequest.SerializeToString,
                response_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.VisualisationResponse.FromString,
                _registered_method=True)
        self.Update = channel.unary_unary(
                '/lara_django.lara_django_data.VisualisationController/Update',
                request_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.VisualisationRequest.SerializeToString,
                response_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.VisualisationResponse.FromString,
                _registered_method=True)
        self.UploadFile = channel.stream_unary(
                '/lara_django.lara_django_data.VisualisationController/UploadFile',
                request_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.FileUploadChunk.SerializeToString,
                response_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.FileUploadInfo.FromString,
                _registered_method=True)
        self.UploadImage = channel.stream_unary(
                '/lara_django.lara_django_data.VisualisationController/UploadImage',
                request_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ImageUploadChunk.SerializeToString,
                response_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ImageUploadInfo.FromString,
                _registered_method=True)


class VisualisationControllerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Create(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Destroy(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DownloadFile(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DownloadImage(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PartialUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Retrieve(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RetrieveByNameNamespace(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UploadFile(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UploadImage(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_VisualisationControllerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.VisualisationRequest.FromString,
                    response_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.VisualisationResponse.SerializeToString,
            ),
            'Destroy': grpc.unary_unary_rpc_method_handler(
                    servicer.Destroy,
                    request_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.VisualisationDestroyRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'DownloadFile': grpc.unary_stream_rpc_method_handler(
                    servicer.DownloadFile,
                    request_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.FileDownloadInfo.FromString,
                    response_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.FileDownloadChunk.SerializeToString,
            ),
            'DownloadImage': grpc.unary_stream_rpc_method_handler(
                    servicer.DownloadImage,
                    request_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ImageDownloadInfo.FromString,
                    response_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ImageDownloadChunk.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.VisualisationListRequest.FromString,
                    response_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.VisualisationListResponse.SerializeToString,
            ),
            'PartialUpdate': grpc.unary_unary_rpc_method_handler(
                    servicer.PartialUpdate,
                    request_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.VisualisationPartialUpdateRequest.FromString,
                    response_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.VisualisationResponse.SerializeToString,
            ),
            'Retrieve': grpc.unary_unary_rpc_method_handler(
                    servicer.Retrieve,
                    request_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.VisualisationRetrieveRequest.FromString,
                    response_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.VisualisationResponse.SerializeToString,
            ),
            'RetrieveByNameNamespace': grpc.unary_unary_rpc_method_handler(
                    servicer.RetrieveByNameNamespace,
                    request_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.VisualisationRetrieveByNameNSRequest.FromString,
                    response_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.VisualisationResponse.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.VisualisationRequest.FromString,
                    response_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.VisualisationResponse.SerializeToString,
            ),
            'UploadFile': grpc.stream_unary_rpc_method_handler(
                    servicer.UploadFile,
                    request_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.FileUploadChunk.FromString,
                    response_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.FileUploadInfo.SerializeToString,
            ),
            'UploadImage': grpc.stream_unary_rpc_method_handler(
                    servicer.UploadImage,
                    request_deserializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ImageUploadChunk.FromString,
                    response_serializer=lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ImageUploadInfo.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'lara_django.lara_django_data.VisualisationController', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('lara_django.lara_django_data.VisualisationController', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class VisualisationController(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_data.VisualisationController/Create',
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.VisualisationRequest.SerializeToString,
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.VisualisationResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Destroy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_data.VisualisationController/Destroy',
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.VisualisationDestroyRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DownloadFile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/lara_django.lara_django_data.VisualisationController/DownloadFile',
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.FileDownloadInfo.SerializeToString,
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.FileDownloadChunk.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DownloadImage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/lara_django.lara_django_data.VisualisationController/DownloadImage',
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ImageDownloadInfo.SerializeToString,
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ImageDownloadChunk.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_data.VisualisationController/List',
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.VisualisationListRequest.SerializeToString,
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.VisualisationListResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def PartialUpdate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_data.VisualisationController/PartialUpdate',
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.VisualisationPartialUpdateRequest.SerializeToString,
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.VisualisationResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Retrieve(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_data.VisualisationController/Retrieve',
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.VisualisationRetrieveRequest.SerializeToString,
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.VisualisationResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RetrieveByNameNamespace(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_data.VisualisationController/RetrieveByNameNamespace',
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.VisualisationRetrieveByNameNSRequest.SerializeToString,
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.VisualisationResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_data.VisualisationController/Update',
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.VisualisationRequest.SerializeToString,
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.VisualisationResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UploadFile(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(
            request_iterator,
            target,
            '/lara_django.lara_django_data.VisualisationController/UploadFile',
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.FileUploadChunk.SerializeToString,
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.FileUploadInfo.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UploadImage(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(
            request_iterator,
            target,
            '/lara_django.lara_django_data.VisualisationController/UploadImage',
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ImageUploadChunk.SerializeToString,
            lara__django__data__grpc_dot_v1_dot_lara__django__data__pb2.ImageUploadInfo.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
